@@ -37,6 +37,16 @@
 #include <string.h>
 #include <dlfcn.h>
 #include <unistd.h>
+#ifdef ANDROID
+#include <cutils/log.h>
+/* support versions < JellyBean */
+#ifndef ALOGE
+#define ALOGE LOGE
+#endif
+#ifndef ALOGI
+#define ALOGI LOGI
+#endif
+#endif
 
 #define DRIVER_EXTENSION	"_drv_video.so"
 
@@ -50,7 +60,7 @@
 
 /*
  * read a config "env" for libva.conf or from environment setting
- * liva.conf has higher priority
+ * libva.conf has higher priority
  * return 0: the "env" is set, and the value is copied into env_value
  *        1: the env is not set
  */
@@ -65,13 +75,13 @@ int va_parseConfig(char *env, char *env_value)
     
     fp = fopen("/etc/libva.conf", "r");
     while (fp && (fgets(oneline, 1024, fp) != NULL)) {
-	if (strlen(oneline) == 1)
-	    continue;
+        if (strlen(oneline) == 1)
+            continue;
         token = strtok_r(oneline, "=\n", &saveptr);
-	value = strtok_r(NULL, "=\n", &saveptr);
+        value = strtok_r(NULL, "=\n", &saveptr);
 
-	if (NULL == token || NULL == value)
-	    continue;
+        if (NULL == token || NULL == value)
+            continue;
 
         if (strcmp(token, env) == 0) {
             if (env_value) {
@@ -108,10 +118,8 @@ int vaDisplayIsValid(VADisplay dpy)
 
 static void default_log_error(const char *buffer)
 {
-# ifdef ANDROID_ALOG
+# ifdef ANDROID
     ALOGE("%s", buffer);
-# elif ANDROID_LOG
-    LOGE("%s", buffer);
 # else
     fprintf(stderr, "libva error: %s", buffer);
 # endif
@@ -119,10 +127,8 @@ static void default_log_error(const char *buffer)
 
 static void default_log_info(const char *buffer)
 {
-# ifdef ANDROID_ALOG
+# ifdef ANDROID
     ALOGI("%s", buffer);
-# elif ANDROID_LOG
-    LOGI("%s", buffer);
 # else
     fprintf(stderr, "libva info: %s", buffer);
 # endif
@@ -153,6 +159,24 @@ vaMessageCallback vaSetInfoCallback(vaMessageCallback callback)
     return old_callback;
 }
 
+void va_MessagingInit()
+{
+#if ENABLE_VA_MESSAGING
+    char env_value[1024];
+
+    if (va_parseConfig("LIBVA_MESSAGING_LEVEL", &env_value[0]) == 0) {
+        if (strcmp(env_value, "0") == 0) {
+            vaSetInfoCallback(NULL);
+            vaSetErrorCallback(NULL);
+        }
+
+        if (strcmp(env_value, "1") == 0) {
+            vaSetInfoCallback(NULL);
+        }
+    }
+#endif
+}
+
 void va_errorMessage(const char *msg, ...)
 {
 #if ENABLE_VA_MESSAGING
@@ -585,6 +609,8 @@ VAStatus vaInitialize (
 
     va_FoolInit(dpy);
 
+    va_MessagingInit();
+
     va_infoMessage("VA-API version %s\n", VA_VERSION_S);
 
     vaStatus = va_getDriverName(dpy, &driver_name);
